<?php

namespace Litecms\Demo\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Demo\Events\DemoRestaurantAction as DemoRestaurantActionEvent;
use Litecms\Demo\Notifications\DemoRestaurantAction as DemoRestaurantActionNotification;
use Litepie\Actions\Concerns\AsAction;

class DemoRestaurantAction
{
    use AsAction;

    private $allowedActions = [
        'before' => [],
        'after' => ['create'],
    ];

    /**
     * Handle the DemoRestaurantActionEvent.
     *
     * @param   DemoRestaurantActionEvent  $event
     * @return mixed
     */
    public function handle(DemoRestaurantActionEvent $event)
    {
        $function = Str::camel($event->action);
        return $this->$function($event);
    }

    /**
     * Create a new $demo_restaurant.
     *
     * @param   DemoRestaurantActionEvent  $event
     * @return void
     */
    public function create(DemoRestaurantActionEvent $event)
    {
        $client = $event->$demo_restaurant->client;
        Notification::send($client, new DemoRestaurantActionNotification($event));
    }

    /**
     * Handle the DemoRestaurantActionEvent as a listener.
     *
     * @param   DemoRestaurantActionEvent  $event
     * @return mixed
     */
    public function asListener(DemoRestaurantActionEvent $event)
    {
        if ($this->isAllowed($event)) {
            return $this->handle($event);
        }
    }

    /**
     * Check if the event action is allowed.
     *
     * @param   DemoRestaurantActionEvent  $event
     * @return bool
     */
    private function isAllowed(DemoRestaurantActionEvent $event)
    {
        if ($event->when == 'before' &&
            !in_array($event->action, $this->allowedActions['before'])) {
            return false;
        }

        if (($event->when == 'after' &&
            !in_array($event->action, $this->allowedActions['after']))
        ) {
            return false;
        }

        return true;
    }
}
