<?php

namespace Litecms\Demo\Listeners;

use Illuminate\Support\Facades\Notification;
use Illuminate\Support\Str;
use Litecms\Demo\Events\DemoRestaurantWorkflow as DemoRestaurantWorkflowEvent;
use Litecms\Demo\Notifications\DemoRestaurantWorkflow as DemoRestaurantWorkflowNotification;
use Litepie\Actions\Concerns\AsAction;

class DemoRestaurantWorkflow
{
    use AsAction;

    private $allowedTransitions = [
        'before' => [],
        'after' => ['publish', 'submit', 'approve'],
    ];

    public function handle(DemoRestaurantWorkflowEvent $event)
    {
        $function = Str::camel($event->transition);
        return $this->$function($event);
    }

    /**
     * Sends a notification to the client when the $demo_restaurant is submitted.
     *
     * @param DemoRestaurantWorkflowEvent $event The event object.
     * @return void
     */
    public function submit(DemoRestaurantWorkflowEvent $event)
    {
        $client = $event->$demo_restaurant->client;
        Notification::send($client, new DemoRestaurantWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $demo_restaurant is published.
     *
     * @param DemoRestaurantWorkflowEvent $event The event object.
     * @return void
     */
    public function publish(DemoRestaurantWorkflowEvent $event)
    {
        $client = $event->$demo_restaurant->client;
        Notification::send($client, new DemoRestaurantWorkflowNotification($event));
    }

    /**
     * Sends a notification to the client when the $demo_restaurant is approved.
     *
     * @param DemoRestaurantWorkflowEvent $event The event object.
     * @return void
     */
    public function approve(DemoRestaurantWorkflowEvent $event)
    {
        $client = $event->$demo_restaurant->client;
        Notification::send($client, new DemoRestaurantWorkflowNotification($event));
    }

    /**
     * Handles the $demo_restaurant workflow event as a listener.
     *
     * @param DemoRestaurantWorkflowEvent $event The event object.
     * @return void
     */
    public function asListener(DemoRestaurantWorkflowEvent $event)
    {
        if (($event->when == 'before' &&
            in_array($event->transition, $this->allowedTransitions['before']) ||
            $event->when == 'after' &&
            in_array($event->transition, $this->allowedTransitions['after']))
        ) {
            return $this->handle($event);
        }
    }
}
