<?php

namespace Litecms\Demo\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\Demo\Models\DemoRestaurant;

class DemoRestaurantPolicy
{


    /**
     * Determine if the given user can view the demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     * @param DemoRestaurant $demo_restaurant
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, DemoRestaurant $demo_restaurant)
    {
        if ($authUser->canDo('demo.demo_restaurant.view') && $authUser->isAdmin()) {
            return true;
        }

        return $demo_restaurant->user_id == user_id() && $demo_restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can create a demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('demo.demo_restaurant.create');
    }

    /**
     * Determine if the given user can update the given demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     * @param DemoRestaurant $demo_restaurant
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, DemoRestaurant $demo_restaurant)
    {
        if ($authUser->canDo('demo.demo_restaurant.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $demo_restaurant->user_id == user_id() && $demo_restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, DemoRestaurant $demo_restaurant)
    {
        return $demo_restaurant->user_id == user_id() && $demo_restaurant->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, DemoRestaurant $demo_restaurant)
    {
        if ($authUser->canDo('demo.demo_restaurant.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given demo_restaurant.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, DemoRestaurant $demo_restaurant)
    {
        if ($authUser->canDo('demo.demo_restaurant.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
